@@ -1,6 +1,12 @@
-from typing import Dict, List, Optional, Text, Tuple, Union
+from typing import List, Optional, Text, Tuple, Union
 
-from vector_search_api.schema import Record
+from vector_search_api.schema import (
+    FetchResult,
+    Index,
+    QueryResult,
+    Record,
+    UpsertResult,
+)
 
 
 class BaseVectorSearch:
@@ -13,23 +19,28 @@ class BaseVectorSearch:
         self.dims = int(dims) if dims else None
         self.kwargs = kwargs
 
-    def describe(self) -> Dict:
+    def describe(self) -> "Index":
         """Describe the api status."""
 
         raise NotImplementedError()
 
+    def fetch(self, ids: Union[List[Text], Text]) -> "FetchResult":
+        """Fetch record by id."""
+
+        raise NotImplementedError()
+
     def query(
         self,
         vector: List[float],
         top_k: int = 3,
         include_values: bool = False,
         include_metadata: bool = False,
-    ) -> Dict:
+    ) -> "QueryResult":
         """Query vector search."""
 
         raise NotImplementedError()
 
-    def upsert(self, records: List[Union[Record, Tuple]]) -> Dict:
+    def upsert(self, records: List[Union[Record, Tuple]]) -> UpsertResult:
         """Upsert records."""
 
         raise NotImplementedError()
